@@ -25,6 +25,69 @@ om_data <- function(year, level) {
     stop(paste0("Level ", level, " is not recognized"))
   }
 
+  # ============================================================================
+  # Processing functions
+  # ============================================================================
+
+  process_2011_2016 <- function(year, url, format) {
+    # Gets the page name for the given level and year as "page"
+    if (level == "DAUID") {
+      prefix <- "DA"
+    }
+    else {
+      prefix <- level
+    }
+
+    if (year == "2011" || level == "DAUID") {
+      page <- paste0(prefix, "_", year)
+    }
+    else {
+      page <- paste0(year, "_", prefix)
+    }
+
+    # Loads the worksheet into a temporary file (tf)
+    tryCatch(
+      GET(url, write_disk(tf <- tempfile(fileext=format))),
+      # Creates an error if the file is unable to download
+      error = function(e) stop("Data file was unable to be downloaded")
+    )
+
+    # Loads a dataframe containing marginalization data
+    phodata <- read_excel(tf, sheet=page)
+    colnames(phodata) <- toupper(colnames(phodata))
+
+    return(phodata)
+  }
+
+
+
+  process_2021 <- function(url) {
+    # Gets the page name for the given level and year as "page"
+    if (level == "DAUID") {
+      page <- paste0("DA_", year)
+    }
+    else {
+      page <- paste0(year, "_", level)
+    }
+
+    # Loads the worksheet into a temporary file (tf)
+    tryCatch(
+      GET(url, write_disk(tf <- tempfile(fileext=".xlsx"))),
+      # Creates an error if the file is unable to download
+      error = function(e) stop("Data file was unable to be downloaded")
+    )
+
+    # Loads a dataframe containing marginalization data
+    phodata <- read_excel(tf, sheet=page)
+    colnames(phodata) <- toupper(colnames(phodata))
+
+    return(phodata)
+  }
+
+  #=============================================================================
+  # Main Switch
+  #=============================================================================
+
   # Gets the correct information for a given year
   switch(year,
          # url       <- URL for the marginalization data
@@ -41,12 +104,16 @@ om_data <- function(year, level) {
          },
          "2011"={
            url <- "https://www.publichealthontario.ca/-/media/Data-Files/index-on-marg-2011.xlsx?la=en&sc_lang=en&hash=88EFEB83D1A1DFC5A90517AE2E71C855"
-           format <- ".xlsx"
+           phodata <- process_2011_2016("2011", url, ".xlsx")
          },
          "2016"={
            #url <- "https://www.publichealthontario.ca/-/media/Data-Files/index-on-marg.xls?sc_lang=en"
            url <- "https://www.publichealthontario.ca/-/media/Data-Files/index-on-marg-2016.xls?sc_lang=en&rev=be5ab11ce0cc4fe5ab99ee66d359fd00&hash=8AE291D54B3AD013A106D27139218CE8"
-           format <- ".xls"
+           phodata <- process_2011_2016("2016", url, ".xls")
+         },
+         "2021"={
+           url <- "https://www.publichealthontario.ca/-/media/Data-Files/index-on-marg.xlsx?rev=c778f01c70294d779131bbdb50c23049&sc_lang=en"
+           phodata <- process_2021(url)
          },
          {
            # Breaks if an invalid ON-Marg year is entered
@@ -54,32 +121,5 @@ om_data <- function(year, level) {
          }
   )
 
-  # Gets the page name for the given level and year as "page"
-  if (level == "DAUID") {
-    prefix <- "DA"
-  }
-  else {
-    prefix <- level
-  }
-
-  if (year == "2011" || level == "DAUID") {
-    page <- paste0(prefix, "_", year)
-  }
-  else {
-    page <- paste0(year, "_", prefix)
-  }
-
-  # Loads the worksheet into a temporary file (tf)
-  tryCatch(
-    GET(url, write_disk(tf <- tempfile(fileext=format))),
-    # Creates an error if the file is unable to download
-    error = function(e) stop("Data file was unable to be downloaded")
-  )
-
-  # Loads a dataframe containing marginalization data
-  phodata <- read_excel(tf, sheet=page)
-  colnames(phodata) <- toupper(colnames(phodata))
-
-
   return(phodata)
 }
